==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/Term__5fc.h <==
// public abstract class polyglot.ext.jl.ast.Term_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd12e62b850e429 polyglot_ext_jl_ast_Term__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Node__5fc

#include "polyglot/ext/jl/ast/Node__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_Term__5fc_H_
#define _JC_polyglot_ext_jl_ast_Term__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_CFGBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	_jc_polyglot_ext_jl_ast_Term__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$refs	_jc_polyglot_ext_jl_ast_Term__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$nonrefs	_jc_polyglot_ext_jl_ast_Term__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$object	_jc_polyglot_ext_jl_ast_Term__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_Term__5fc$vmethods	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_Term__5fc$vtable	_jc_polyglot_ext_jl_ast_Term__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_Term__5fc$vtype	_jc_polyglot_ext_jl_ast_Term__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_Term__5fc$method$_init$02a94c1d4b5cc142(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$acceptCFG$971a2b57163f2742(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$entry$617ff8f143060243(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *);
extern jboolean _jc_polyglot_ext_jl_ast_Term__5fc$method$reachable$80b3a95e69168795(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$reachable$1b56f401b2f699a4(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$acceptCFG$971a2b57163f2742;
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$entry$617ff8f143060243;
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$reachable$80b3a95e69168795;
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$reachable$1b56f401b2f699a4;

// Static methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$listEntry$117017c820187bfc(_jc_env *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_Term__5fc$vmethods {
	struct _jc_object	*(*acceptCFG$971a2b57163f2742)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *, struct _jc_object *);
	struct _jc_object	*(*entry$617ff8f143060243)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *);
	jboolean	(*reachable$80b3a95e69168795)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *);
	struct _jc_object	*(*reachable$1b56f401b2f699a4)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, jboolean);
};

// Vtable
struct _jc_polyglot_ext_jl_ast_Term__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods	polyglot_ext_jl_ast_Term__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_Term__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_Term__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Term__5fc$refs {
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs {
	jboolean	reachable;
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Term__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	polyglot_ext_jl_ast_Term__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_Term__5fc$object {
	_jc_polyglot_ext_jl_ast_Term__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_Term__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_Term__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_Term__5fc$vtype _jc_polyglot_ext_jl_ast_Term__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_Term__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_Term__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_Term__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/Term__5fc.h <==
// public abstract class polyglot.ext.jl.ast.Term_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd12e62b850e429 polyglot_ext_jl_ast_Term__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Node__5fc

#include "polyglot/ext/jl/ast/Node__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_Term__5fc_H_
#define _JC_polyglot_ext_jl_ast_Term__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_CFGBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	_jc_polyglot_ext_jl_ast_Term__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$refs	_jc_polyglot_ext_jl_ast_Term__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$nonrefs	_jc_polyglot_ext_jl_ast_Term__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Term__5fc$object	_jc_polyglot_ext_jl_ast_Term__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_Term__5fc$vmethods	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_Term__5fc$vtable	_jc_polyglot_ext_jl_ast_Term__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_Term__5fc$vtype	_jc_polyglot_ext_jl_ast_Term__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_Term__5fc$method$_init$02a94c1d4b5cc142(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$acceptCFG$971a2b57163f2742(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$entry$617ff8f143060243(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_ast_Term__5fc$method$reachable$80b3a95e69168795(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$reachable$1b56f401b2f699a4(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$acceptCFG$971a2b57163f2742;
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$entry$617ff8f143060243;
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$reachable$80b3a95e69168795;
extern _jc_method _jc_polyglot_ext_jl_ast_Term__5fc$method_info$reachable$1b56f401b2f699a4;

// Static methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Term__5fc$method$listEntry$117017c820187bfc(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_Term__5fc$vmethods {
	struct _jc_object	*(*acceptCFG$971a2b57163f2742)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*entry$617ff8f143060243)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *) _JC_JCNI_ATTR;
	jboolean	(*reachable$80b3a95e69168795)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*reachable$1b56f401b2f699a4)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Term__5fc$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_ast_Term__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods	polyglot_ext_jl_ast_Term__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_Term__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_Term__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Term__5fc$refs {
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs {
	jboolean	reachable;
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Term__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	polyglot_ext_jl_ast_Term__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_Term__5fc$object {
	_jc_polyglot_ext_jl_ast_Term__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_Term__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_Term__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_Term__5fc$vtype _jc_polyglot_ext_jl_ast_Term__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_Term__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_Term__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_Term__5fc_H_ */
